[Checkins] SVN: zope.localpermission/ Split LocalPermission to zope.localpermission.

Dan Korostelev nadako at gmail.com
Wed Mar 11 12:07:11 EDT 2009


Log message for revision 97843:
  Split LocalPermission to zope.localpermission.

Changed:
  A   zope.localpermission/
  A   zope.localpermission/trunk/
  U   zope.localpermission/trunk/CHANGES.txt
  U   zope.localpermission/trunk/README.txt
  U   zope.localpermission/trunk/buildout.cfg
  U   zope.localpermission/trunk/setup.py
  U   zope.localpermission/trunk/src/zope/__init__.py
  D   zope.localpermission/trunk/src/zope/app/
  A   zope.localpermission/trunk/src/zope/localpermission/
  U   zope.localpermission/trunk/src/zope/localpermission/__init__.py
  D   zope.localpermission/trunk/src/zope/localpermission/security/

-=-

Property changes on: zope.localpermission/trunk
___________________________________________________________________
Added: svn:ignore
   + bin
build
dist
lib
develop-eggs
eggs
parts
.installed.cfg
coverage


Modified: zope.localpermission/trunk/CHANGES.txt
===================================================================
--- zope.app.security/trunk/CHANGES.txt	2009-03-11 15:13:37 UTC (rev 97840)
+++ zope.localpermission/trunk/CHANGES.txt	2009-03-11 16:07:11 UTC (rev 97843)
@@ -2,92 +2,8 @@
 CHANGES
 =======
 
-3.6.3 (unreleased)
+3.7.0 (unreleased)
 ------------------
 
-- ...
-
-3.6.2 (2009-03-10)
-------------------
-
-- The `Allow`, `Deny` and `Unset` permission settings was preferred to
-  be imported from ``zope.securitypolicy.interfaces`` for a long time
-  and now they are completely moved there from ``zope.app.security.settings``
-  as well as the ``PermissionSetting`` class. The only thing left for
-  backward compatibility is the import of Allow/Unset/Deny constants if
-  ``zope.securitypolicy`` is installed to allow unpickling of security
-  settings.
-
-3.6.1 (2009-03-09)
-------------------
-
-- Depend on new ``zope.password`` package instead of ``zope.app.authentication``
-  to get password managers for the authentication utility, thus remove
-  dependency on ``zope.app.authentication``.
-
-- Use template for AuthUtilitySearchView instead of ugly HTML
-  constructing in the python code.
-
-- Bug: The `sha` and `md5` modules has been deprecated in Python 2.6.
-  Whenever the ZCML of this package was included when using Python 2.6,
-  a deprecation warning had been raised stating that `md5` and `sha` have
-  been deprecated. Provided a simple condition to check whether Python 2.6
-  or later is installed by checking for the presense of `json` module
-  thas was added only in Python 2.6 and thus optionally load the security
-  declaration for `md5` and `sha`.
-
-- Remove deprecated code, thus removing explicit dependency on
-  zope.deprecation and zope.deferredimport.
-
-- Cleanup code a bit, replace old __used_for__ statements by ``adapts``
-  calls.
-
-3.6.0 (2009-01-31)
-------------------
-
-- Changed mailing list address to zope-dev at zope.org, because
-  zope3-dev is retired now. Changed "cheeseshop" to "pypi" in
-  the package homepage.
-
-- Moved the `protectclass` module to `zope.security` leaving only a
-  compatibility module here that imports from the new location.
-
-- Moved the <module> directive implementation to `zope.security`.
-
-- Use `zope.container` instead of `zope.app.container`;.
-
-3.5.3 (2008-12-11)
-------------------
-
-- use zope.browser.interfaces.ITerms instead of
-  `zope.app.form.browser.interfaces`.
-
-3.5.2 (2008-07-31)
-------------------
-
-- Bug: It turned out that checking for regex was not much better of an
-  idea, since it causes deprecation warnings in Python 2.4. Thus let's
-  look for a library that was added in Python 2.5.
-
-3.5.1 (2008-06-24)
-------------------
-
-- Bug: The `gopherlib` module has been deprecated in Python 2.5. Whenever the
-  ZCML of this package was included when using Python 2.5, a deprecation
-  warning had been raised stating that `gopherlib` has been
-  deprecated. Provided a simple condition to check whether Python 2.5 or later
-  is installed by checking for the deleted `regex` module and thus optionally
-  load the security declaration for `gopherlib`.
-
-3.5.0 (2008-02-05)
-------------------
-
-- Feature:
-  `zope.app.security.principalregistry.PrincipalRegistry.getPrincipal` returns
-  `zope.security.management.system_user` when its id is used for the search
-  key.
-
-3.4.0 (2007-10-27)
-------------------
-
-- Initial release independent of the main Zope tree.
+Initial release. This package was extracted from zope.app.security to separate
+the functionality without additional dependencies.

Modified: zope.localpermission/trunk/README.txt
===================================================================
--- zope.app.security/trunk/README.txt	2009-03-11 15:13:37 UTC (rev 97840)
+++ zope.localpermission/trunk/README.txt	2009-03-11 16:07:11 UTC (rev 97843)
@@ -1,2 +1,2 @@
-This package provides several components integrating the Zope security
-implementation into zope 3 applications.
+This package implements local persistent permissions for zope.security that
+can be added and registered per site.

Modified: zope.localpermission/trunk/buildout.cfg
===================================================================
--- zope.app.security/trunk/buildout.cfg	2009-03-11 15:13:37 UTC (rev 97840)
+++ zope.localpermission/trunk/buildout.cfg	2009-03-11 16:07:11 UTC (rev 97843)
@@ -1,7 +1,18 @@
 [buildout]
 develop = .
-parts = test
+parts = test coverage-test coverage-report
 
 [test]
 recipe = zc.recipe.testrunner
-eggs = zope.app.security [test]
+eggs = zope.localpermission
+
+[coverage-test]
+recipe = zc.recipe.testrunner
+eggs = zope.localpermission
+defaults = ['--coverage', '../../coverage']
+
+[coverage-report]
+recipe = zc.recipe.egg
+eggs = z3c.coverage
+scripts = coverage=coverage-report
+arguments = ('coverage', 'coverage/report')

Modified: zope.localpermission/trunk/setup.py
===================================================================
--- zope.app.security/trunk/src/zope/__init__.py	2009-03-11 15:13:37 UTC (rev 97840)
+++ zope.localpermission/trunk/src/zope/__init__.py	2009-03-11 16:07:11 UTC (rev 97843)
@@ -1,8 +1 @@
-# this is a namespace package
-try:
-    import pkg_resources
-    pkg_resources.declare_namespace(__name__)
-except ImportError:
-    import pkgutil
-    __path__ = pkgutil.extend_path(__path__, __name__)
-
+__import__('pkg_resources').declare_namespace(__name__)

Modified: zope.localpermission/trunk/src/zope/localpermission/__init__.py
===================================================================
--- zope.app.security/trunk/src/zope/app/__init__.py	2009-03-11 15:13:37 UTC (rev 97840)
+++ zope.localpermission/trunk/src/zope/localpermission/__init__.py	2009-03-11 16:07:11 UTC (rev 97843)
@@ -1,8 +1 @@
-# this is a namespace package
-try:
-    import pkg_resources
-    pkg_resources.declare_namespace(__name__)
-except ImportError:
-    import pkgutil
-    __path__ = pkgutil.extend_path(__path__, __name__)
-
+from zope.localpermission.permission import LocalPermission



More information about the Checkins mailing list
--- zope.app.security/trunk/setup.py	2009-03-11 15:13:37 UTC (rev 97840)
+++ zope.localpermission/trunk/setup.py	2009-03-11 16:07:11 UTC (rev 97843)
@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2006 Zope Corporation and Contributors.
+# Copyright (c) 2009 Zope Corporation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -11,7 +11,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
 """Setup for zope.app.security package
 
 $Id$
 """
@@ -21,32 +21,17 @@
 def read(*rnames):
     return open(os.path.join(os.path.dirname(__file__), *rnames)).read()
 
-setup(name='zope.app.security',
-      version = '3.6.3dev',
+setup(name='zope.localpermission',
+      version = '3.7.0dev',
       author='Zope Corporation and Contributors',
       author_email='zope-dev at zope.org',
-      description='Security Components for Zope 3 Applications',
+      description='Local Persistent Permissions for zope.security',
       long_description=(
           read('README.txt')
           + '\n\n' +
-          'Detailed Documentation\n' +
-          '======================\n'
-          + '\n\n' +
-          read('src', 'zope', 'app', 'security', 'globalprincipals.txt')
-          + '\n\n' +
-          read('src', 'zope', 'app', 'security', 'logout.txt')
-          + '\n\n' +
-          read('src', 'zope', 'app', 'security', 'browser',
-               'authutilitysearchview.txt')
-          + '\n\n' +
-          read('src', 'zope', 'app', 'security', 'browser', 'loginlogout.txt')
-          + '\n\n' +
-          read('src', 'zope', 'app', 'security', 'browser',
-               'principalterms.txt')
-          + '\n\n' +
           read('CHANGES.txt')
           ),
-      keywords = "zope3 security authentication principal ftp http",
+      keywords = "zope security persistent local permission",
       classifiers = [
           'Development Status :: 5 - Production/Stable',
           'Environment :: Web Environment',
@@ -57,31 +42,18 @@
           'Operating System :: OS Independent',
           'Topic :: Internet :: WWW/HTTP',
           'Framework :: Zope3'],
-      url='http://pypi.python.org/pypi/zope.app.security',
+      url='http://pypi.python.org/pypi/zope.localpermission',
       license='ZPL 2.1',
       packages=find_packages('src'),
       package_dir = {'': 'src'},
-      namespace_packages=['zope', 'zope.app'],
-      extras_require=dict(test=['zope.app.testing']),
+      namespace_packages=['zope'],
       install_requires=['setuptools',
-                        'zope.browser',
-                        'zope.app.component',
-                        'zope.app.form',
-                        'zope.app.pagetemplate',
-                        'zope.app.publisher',
+                        'ZODB3',
                         'zope.component',
-                        'zope.configuration',
-                        'zope.container',
-                        'zope.i18n',
                         'zope.i18nmessageid',
                         'zope.interface',
                         'zope.location',
-                        'zope.password',
-                        'zope.publisher',
-                        'zope.schema',
                         'zope.security',
-                        'zope.site',
-                        'ZODB3',
                         ],
       include_package_data = True,
       zip_safe = False,
@@ -11,7 +11,7 @@
 #
 ##############################################################################
-"""Setup for zope.app.security package
+"""Setup for zope.localpermission package
 
 $Id$

Modified: zope.localpermission/trunk/src/zope/__init__.py
===================================================================